A bootstrap3 version of the bootstrap theme.

There is a variant called bootstrap3-gradients which uses an extra CSS
file for a *visually enhanced experience* (according to Bootstrap
developers at least).  This one uses the default bootstrap3 flat look.

This theme supports Bootswtach font/color schemes (unlike
bootstrap3-gradients) through the `nikola bootswatch_theme` command.
